polar2grid.tests.test\_add\_coastlines module
=============================================

.. automodule:: polar2grid.tests.test_add_coastlines
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
